@@ -3,13 +3,16 @@
  * @copyright Copyright (c) 2016, ownCloud, Inc.
  *
  * @author Arne Hamann <kontakt+github@arne.email>
+ * @author Arthur Schiwon <blizzz@arthur-schiwon.de>
  * @author Björn Schießle <bjoern@schiessle.org>
+ * @author call-me-matt <nextcloud@matthiasheinisch.de>
+ * @author Christoph Wurst <christoph@winzerhof-wurst.at>
  * @author Daniel Kesselberg <mail@danielkesselberg.de>
  * @author Georg Ehrke <oc.list@georgehrke.com>
  * @author Joas Schilling <coding@schilljs.com>
- * @author John Molakvoæ (skjnldsv) <skjnldsv@protonmail.com>
+ * @author John Molakvoæ <skjnldsv@protonmail.com>
  * @author Julius Härtl <jus@bitgrid.net>
- * @author labor4 <schreibtisch@labor4.ch>
+ * @author Thomas Citharel <nextcloud@tcit.fr>
  * @author Thomas Müller <thomas.mueller@tmit.eu>
  *
  * @license AGPL-3.0
@@ -27,18 +30,18 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>
  *
  */
-
 namespace OCA\DAV\CardDAV;
 
+use OCA\DAV\Db\PropertyMapper;
 use OCP\Constants;
-use OCP\IAddressBook;
+use OCP\IAddressBookEnabled;
 use OCP\IURLGenerator;
 use Sabre\VObject\Component\VCard;
 use Sabre\VObject\Property;
 use Sabre\VObject\Reader;
 use Sabre\VObject\UUIDUtil;
 
-class AddressBookImpl implements IAddressBook {
+class AddressBookImpl implements IAddressBookEnabled {
 
 	/** @var CardDavBackend */
 	private $backend;
@@ -52,6 +55,12 @@ class AddressBookImpl implements IAddressBook {
 	/** @var IURLGenerator */
 	private $urlGenerator;
 
+	/** @var PropertyMapper */
+	private $propertyMapper;
+
+	/** @var string|null */
+	private $userId;
+
 	/**
 	 * AddressBookImpl constructor.
 	 *
@@ -59,16 +68,22 @@ class AddressBookImpl implements IAddressBook {
 	 * @param array $addressBookInfo
 	 * @param CardDavBackend $backend
 	 * @param IUrlGenerator $urlGenerator
+	 * @param PropertyMapper $propertyMapper
+	 * @param string|null $userId
 	 */
 	public function __construct(
-			AddressBook $addressBook,
-			array $addressBookInfo,
-			CardDavBackend $backend,
-			IURLGenerator $urlGenerator) {
+		AddressBook $addressBook,
+		array $addressBookInfo,
+		CardDavBackend $backend,
+		IURLGenerator $urlGenerator,
+		PropertyMapper $propertyMapper,
+		?string $userId) {
 		$this->addressBook = $addressBook;
 		$this->addressBookInfo = $addressBookInfo;
 		$this->backend = $backend;
 		$this->urlGenerator = $urlGenerator;
+		$this->propertyMapper = $propertyMapper;
+		$this->userId = $userId;
 	}
 
 	/**
@@ -82,7 +97,6 @@ class AddressBookImpl implements IAddressBook {
 	/**
 	 * @return string defining the unique uri
 	 * @since 16.0.0
-	 * @return string
 	 */
 	public function getUri(): string {
 		return $this->addressBookInfo['uri'];
@@ -105,6 +119,10 @@ class AddressBookImpl implements IAddressBook {
 	 * 	- 'types' boolean (since 15.0.0) If set to true, fields that come with a TYPE property will be an array
 	 *    example: ['id' => 5, 'FN' => 'Thomas Tanghus', 'EMAIL' => ['type => 'HOME', 'value' => 'g@h.i']]
 	 * 	- 'escape_like_param' - If set to false wildcards _ and % are not escaped
+	 * 	- 'limit' - Set a numeric limit for the search results
+	 * 	- 'offset' - Set the offset for the limited search results
+	 * 	- 'wildcard' - Whether the search should use wildcards
+	 * @psalm-param array{types?: bool, escape_like_param?: bool, limit?: int, offset?: int, wildcard?: bool} $options
 	 * @return array an array of contacts which are arrays of key-value-pairs
 	 *  example result:
 	 *  [
@@ -145,7 +163,26 @@ class AddressBookImpl implements IAddressBook {
 		}
 
 		foreach ($properties as $key => $value) {
-			$vCard->$key = $vCard->createProperty($key, $value);
+			if (is_array($value)) {
+				$vCard->remove($key);
+				foreach ($value as $entry) {
+					if (is_string($entry)) {
+						$property = $vCard->createProperty($key, $entry);
+					} else {
+						if (($key === "ADR" || $key === "PHOTO") && is_string($entry["value"])) {
+							$entry["value"] = stripslashes($entry["value"]);
+							$entry["value"] = explode(';', $entry["value"]);
+						}
+						$property = $vCard->createProperty($key, $entry["value"]);
+						if (isset($entry["type"])) {
+							$property->add('TYPE', $entry["type"]);
+						}
+					}
+					$vCard->add($property);
+				}
+			} elseif ($key !== 'URI') {
+				$vCard->$key = $vCard->createProperty($key, $value);
+			}
 		}
 
 		if ($update) {
@@ -183,7 +220,7 @@ class AddressBookImpl implements IAddressBook {
 	}
 
 	/**
-	 * @param object $id the unique identifier to a contact
+	 * @param int $id the unique identifier to a contact
 	 * @return bool successful or not
 	 * @since 5.0.0
 	 */
@@ -249,7 +286,7 @@ class AddressBookImpl implements IAddressBook {
 		];
 
 		foreach ($vCard->children() as $property) {
-			if ($property->name === 'PHOTO' && $property->getValueType() === 'BINARY') {
+			if ($property->name === 'PHOTO' && in_array($property->getValueType(), ['BINARY', 'URI'])) {
 				$url = $this->urlGenerator->getAbsoluteURL(
 					$this->urlGenerator->linkTo('', 'remote.php') . '/dav/');
 				$url .= implode('/', [
@@ -279,12 +316,7 @@ class AddressBookImpl implements IAddressBook {
 			}
 		}
 
-		if (
-			$this->addressBookInfo['principaluri'] === 'principals/system/system' && (
-				$this->addressBookInfo['uri'] === 'system' ||
-				$this->addressBookInfo['{DAV:}displayname'] === $this->urlGenerator->getBaseUrl()
-			)
-		) {
+		if ($this->isSystemAddressBook()) {
 			$result['isLocalSystemBook'] = true;
 		}
 		return $result;
@@ -307,4 +339,47 @@ class AddressBookImpl implements IAddressBook {
 
 		return null;
 	}
+
+	/**
+	 * @inheritDoc
+	 */
+	public function isShared(): bool {
+		if (!isset($this->addressBookInfo['{http://owncloud.org/ns}owner-principal'])) {
+			return false;
+		}
+
+		return $this->addressBookInfo['principaluri']
+			!== $this->addressBookInfo['{http://owncloud.org/ns}owner-principal'];
+	}
+
+	/**
+	 * @inheritDoc
+	 */
+	public function isSystemAddressBook(): bool {
+		return $this->addressBookInfo['principaluri'] === 'principals/system/system' && (
+			$this->addressBookInfo['uri'] === 'system' ||
+			$this->addressBookInfo['{DAV:}displayname'] === $this->urlGenerator->getBaseUrl()
+		);
+	}
+
+	public function isEnabled(): bool {
+		if (!$this->userId) {
+			return true;
+		}
+
+		if ($this->isSystemAddressBook()) {
+			$user = $this->userId ;
+			$uri = 'z-server-generated--system';
+		} else {
+			$user = str_replace('principals/users/', '', $this->addressBookInfo['principaluri']);
+			$uri = $this->addressBookInfo['uri'];
+		}
+		
+		$path = 'addressbooks/users/' . $user . '/' . $uri;
+		$properties = $this->propertyMapper->findPropertyByPathAndName($user, $path, '{http://owncloud.org/ns}enabled');
+		if (count($properties) > 0) {
+			return (bool)$properties[0]->getPropertyvalue();
+		}
+		return true;
+	}
 }
