@@ -74,68 +74,63 @@ OC.L10N.register(
     "Enforce Windows compatibility" : "強制 Windows 相容性",
     "This will block filenames not valid on Windows systems, like using reserved names or special characters. But this will not enforce compatibility of case sensitivity." : "這會封鎖在 Windows 系統上無效的檔案名稱，例如使用保留名稱或特殊字元。但這不會強制區分大小寫的相容性。",
     "File Management" : "檔案管理",
-    "Current directory path" : "目前目錄路徑",
     "Home" : "家目錄",
     "Target folder does not exist any more" : "目標資料夾已不存在了",
     "Reload current directory" : "重新載入目前的目錄",
     "Go to the \"{dir}\" directory" : "前往「{dir}」目錄",
-    "Drag and drop files here to upload" : "將檔案拖放到此處以上傳",
+    "Current directory path" : "目前目錄路徑",
     "Your have used your space quota and cannot upload files anymore" : "您已用完您的空間配額，無法再上傳檔案",
-    "You don’t have permission to upload or create files here" : "您沒有權限在這裡上傳或建立檔案",
+    "You do not have permission to upload or create files here." : "您無權在此上傳或建立檔案。",
+    "Drag and drop files here to upload" : "將檔案拖放到此處以上傳",
     "Favorite" : "喜愛",
     "Back" : "返回",
     "Toggle selection for file \"{displayName}\"" : "切換檔案「{displayName}」的選取",
     "Toggle selection for folder \"{displayName}\"" : "切換資料夾「{displayName}」的選取",
     "File is loading" : "正在載入檔案",
     "Folder is loading" : "正在載入資料夾",
-    "Rename file" : "重新命名檔案",
     "Filename" : "檔案名稱",
     "Folder name" : "資料夾名稱",
     "This node is unavailable" : "此節點不可用",
     "Another entry with the same name already exists." : "已存在另一個同名條目。",
     "Invalid filename." : "無效的檔案名稱。",
     "Renamed \"{oldName}\" to \"{newName}\"" : "已將「{oldName}」重新命名為「{newName}」",
-    "Unknown date" : "未知日期",
+    "Rename file" : "重新命名檔案",
     "Pending" : "待處理",
+    "Unknown date" : "未知日期",
     "Clear filter" : "清除過濾條件",
     "Modified" : "修改時間",
     "Type" : "類型",
     "Active filters" : "作用中的過濾條件",
     "Remove filter" : "移除過濾條件",
     "Total rows summary" : "總列摘要",
+    "Toggle selection for all files and folders" : "切換所有檔案和資料夾的選取",
     "Name" : "名稱",
     "Size" : "大小",
-    "Toggle selection for all files and folders" : "切換所有檔案和資料夾的選取",
-    "Actions" : "動作",
-    "(selected)" : "（已選取）",
-    "\"{displayName}\" failed on some elements " : "「{displayName}」在某些元素上失敗 ",
+    "\"{displayName}\" failed on some elements" : "「{displayName}」在某些元素上失敗",
     "\"{displayName}\" batch action executed successfully" : "「{displayName}」批次動作執行成功",
     "\"{displayName}\" action failed" : "「{displayName}」操作失敗",
-    "{count} selected" : "已選取 {count} 個",
+    "Actions" : "動作",
+    "(selected)" : "（已選取）",
     "List of files and folders." : "檔案與資料夾清單。",
-    "You don’t have permission to upload or create files here." : "您無權在此上傳或建立檔案。",
     "You have used your space quota and cannot upload files anymore." : "您已用完您的空間配額，無法再上傳檔案。",
     "Column headers with buttons are sortable." : "帶有按鈕的欄位標頭為可排序。",
     "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list." : "出於效能考量，此清單未完全呈現。檔案將在您瀏覽清單時呈現。",
     "File not found" : "找不到檔案",
-    "Storage information" : "儲存空間資訊",
-    "Storage quota" : "儲存空間配額",
+    "{count} selected" : "已選取 {count} 個",
     "{usedQuotaByte} used" : "已使用 {usedQuotaByte}",
     "{used} of {quota} used" : "已使用 {used}，共 {quota}",
     "{relative}% used" : "已使用 {relative}%",
     "Could not refresh storage stats" : "無法重新整理儲存空間統計資料",
     "Your storage is full, files can not be updated or synced anymore!" : "您的儲存空間已滿，沒有辦法再更新或是同步檔案！",
-    "Create" : "建立",
+    "Storage information" : "儲存空間資訊",
+    "Storage quota" : "儲存空間配額",
     "New folder" : "新資料夾",
     "Create new folder" : "新增資料夾",
     "This name is already in use." : "此名稱已使用。",
+    "Create" : "建立",
     "Fill template fields" : "檔案範本欄位",
-    "Submitting fields…" : "正在遞交欄位……",
+    "Submitting fields …" : "正在遞交欄位……",
     "Submit" : "遞交",
-    "Transfer ownership of a file or folder" : "轉移檔案或是資料夾的所有權",
-    "Choose file or folder to transfer" : "選擇要轉移的檔案或資料夾",
-    "Change" : "更改",
-    "New owner" : "新的擁有者",
     "Choose a file or folder to transfer" : "選擇要轉移的檔案或資料夾",
     "Transfer" : "轉移",
     "Transfer {path} to {userid}" : "轉移 {path} 給 {userid}",
@@ -143,18 +138,27 @@ OC.L10N.register(
     "Unknown error" : "未知的錯誤",
     "Ownership transfer request sent" : "已送出所有權轉移的請求",
     "Cannot transfer ownership of a file or folder you do not own" : "無法轉移您未擁有的檔案或資料夾的所有權",
+    "Transfer ownership of a file or folder" : "轉移檔案或是資料夾的所有權",
+    "Choose file or folder to transfer" : "選擇要轉移的檔案或資料夾",
+    "Change" : "更改",
+    "New owner" : "新的擁有者",
+    "Keep {old}" : "保留 {old}",
+    "Keep without extension" : "保留但不包含副檔名",
+    "Use {new}" : "使用 {new}",
+    "Remove extension" : "移除副檔名",
+    "Change file extension" : "變更檔案副檔名",
+    "Changing the file extension from \"{old}\" to \"{new}\" may render the file unreadable." : "將檔案副檔名從「{old}」改為「{new}」可能會導致檔案無法讀取。",
+    "Removing the file extension \"{old}\" may render the file unreadable." : "移除檔案副檔名「{old}」可能會導致檔案無法讀取。",
+    "Adding the file extension \"{new}\" may render the file unreadable." : "加入檔案副檔名「{new}」可能會導致檔案無法讀取。",
+    "Do not show this dialog again." : "不要再次顯示此對話方塊。",
     "Select file or folder to link to" : "選取要連結的檔案或資料夾",
     "Choose {file}" : "選擇 {file}",
-    "Loading current folder" : "正在載入目前資料夾",
-    "Retry" : "重試",
-    "No files in here" : "沒有任何檔案",
-    "Upload some content or sync with your devices!" : "在您的裝置同步或上傳一些內容！",
-    "Go back" : "返回",
     "Share" : "分享",
     "Shared by link" : "透過連結分享",
     "Shared" : "已分享",
     "Switch to list view" : "切換至列表檢視",
     "Switch to grid view" : "切換到格狀檢視",
+    "The file could not be found" : "找不到檔案",
     "Upload was cancelled by user" : "使用者已取消上傳",
     "Not enough free space" : "空間不足",
     "Operation is blocked by access control" : "操作已被存取控制封鎖",
@@ -162,13 +166,20 @@ OC.L10N.register(
     "Error during upload, status code {status}" : "上傳時發生錯誤，狀態碼 {status}",
     "Unknown error during upload" : "上傳時發生未知的錯誤",
     "\"{displayName}\" action executed successfully" : "「{displayName}」動作執行成功",
-    "Filter file names…" : "過濾檔案名稱……",
+    "Loading current folder" : "正在載入目前資料夾",
+    "Retry" : "重試",
+    "No files in here" : "沒有任何檔案",
+    "Upload some content or sync with your devices!" : "在您的裝置同步或上傳一些內容！",
+    "Go back" : "返回",
+    "Filter file names …" : "過濾檔案名稱……",
     "Views" : "顯示",
     "Files settings" : "檔案設定",
-    "File cannot be accessed" : "無法存取檔案",
-    "The file could not be found or you do not have permissions to view it. Ask the sender to share it." : "找不到該檔案，或是您沒有檢視該檔案的權限。請寄件者分享。",
     "Your files" : "您的檔案",
     "Open in files" : "在檔案中開啟",
+    "File cannot be accessed" : "無法存取檔案",
+    "The file could not be found or you do not have permissions to view it. Ask the sender to share it." : "找不到該檔案，或是您沒有檢視該檔案的權限。請寄件者分享。",
+    "Clipboard is not available" : "剪貼簿無法使用",
+    "WebDAV URL copied to clipboard" : "WebDAV URL 已複製到剪貼簿",
     "Sort favorites first" : "先排序喜愛",
     "Sort folders before files" : "將資料夾排序在檔案前",
     "Show hidden files" : "顯示隱藏檔",
@@ -181,6 +192,9 @@ OC.L10N.register(
     "Copy to clipboard" : "複製到剪貼簿",
     "Use this address to access your Files via WebDAV" : "使用此位置透過 WebDAV 存取您的檔案",
     "If you have enabled 2FA, you must create and use a new app password by clicking here." : "若您啟用了雙因子認證，您必須點擊此處建立並使用新的應用程式密碼。",
+    "Warnings" : "警告",
+    "Prevent warning dialogs from open or reenable them." : "避免開啟警告對話方塊或重新啟用它們。",
+    "Show a warning dialog when changing a file extension." : "在變更副檔名時顯示警告對話方塊。",
     "Keyboard shortcuts" : "鍵盤快速鍵",
     "Speed up your Files experience with these quick shortcuts." : "使用這些快捷鍵加速您的 Files 體驗。",
     "Open the actions menu for a file" : "開啟檔案的動作選單",
@@ -203,33 +217,29 @@ OC.L10N.register(
     "Toggle the grid view" : "切換網格檢視",
     "Open the sidebar for a file" : "開啟檔案側邊欄",
     "Show those shortcuts" : "顯示這些快捷鍵",
-    "Clipboard is not available" : "剪貼簿無法使用",
-    "WebDAV URL copied to clipboard" : "WebDAV URL 已複製到剪貼簿",
+    "You" : "您",
+    "Shared multiple times with different people" : "與不同的人多次分享",
+    "Error while loading the file data" : "載入檔案資料時發生錯誤",
     "Owner" : "擁有者",
     "Remove from favorites" : "從喜愛中移除",
     "Add to favorites" : "新增至喜愛",
     "Tags" : "標籤",
-    "You" : "您",
-    "Shared multiple times with different people" : "與不同的人多次分享",
-    "Unable to change the favorite state of the file" : "無法變更檔案的喜愛狀態",
-    "Error while loading the file data" : "載入檔案資料時發生錯誤",
+    "Blank" : "空白",
+    "Unable to create new file from template" : "無法從範本建立新檔案",
     "Pick a template for {name}" : "為 {name} 挑選範本",
     "Create a new file with the selected template" : "使用選定的範本建立新檔案",
     "Creating file" : "正在建立檔案",
-    "Blank" : "空白",
-    "Unable to create new file from template" : "無法從範本建立新檔案",
     "Save as {displayName}" : "另存為 {displayName}",
     "Save as …" : "另存為……",
-    "Converting files…" : "正在轉換檔案……",
+    "Converting files …" : "正在轉換檔案……",
     "Failed to convert files: {message}" : "無法轉換檔案：{message}",
     "All files failed to be converted" : "所有檔案轉換失敗",
     "One file could not be converted: {message}" : "一個檔案無法轉換：{message}",
-    "One file could not be converted" : "一個檔案無法轉換",
-    "{count} files could not be converted" : "{count} 個檔案無法轉換",
-    "{count} files successfully converted" : "{count} 個檔案成功轉換",
+    "_One file could not be converted_::_%n files could not be converted_" : ["無法轉換 %n 個檔案"],
+    "_One file successfully converted_::_%n files successfully converted_" : ["成功轉換 %n 個檔案"],
     "Files successfully converted" : "檔案成功轉換",
     "Failed to convert files" : "轉換檔案失敗",
-    "Converting file…" : "正在轉換檔案……",
+    "Converting file …" : "正在轉換檔案……",
     "File successfully converted" : "成功轉換檔案",
     "Failed to convert file: {message}" : "無法轉換檔案：{message}",
     "Failed to convert file" : "無法轉換檔案",
@@ -249,12 +259,6 @@ OC.L10N.register(
     "_You are about to delete {count} item_::_You are about to delete {count} items_" : ["您將要刪除 {count} 個項目"],
     "Confirm deletion" : "確認刪除",
     "Cancel" : "取消",
-    "Edit file locally" : "本機編輯檔案",
-    "The file should now open on your device. If it doesn't, please check that you have the desktop app installed." : "檔案現在應該可以在您的裝置上開啟。如果打不開，請檢查您是否有安裝桌面應用程式。",
-    "Retry and close" : "重試並關閉",
-    "Edit online" : "線上編輯",
-    "Failed to redirect to client" : "重新導向到客戶端失敗",
-    "Edit locally" : "在本機編輯",
     "Moving \"{source}\" to \"{destination}\" …" : "正在移動「{source}」至「{destination}」……",
     "Copying \"{source}\" to \"{destination}\" …" : "正在複製「{source}」至「{destination}」……",
     "You cannot move a file/folder onto itself or into a subfolder of itself" : "您無法將檔案/資料夾移動到其自身或子資料夾中",
@@ -275,6 +279,12 @@ OC.L10N.register(
     "Cancelled move or copy operation" : "已取消移動或複製操作",
     "Open folder {displayName}" : "開啟資料夾 {displayName}",
     "Open in Files" : "以「檔案」開啟",
+    "Open file locally" : "在本機開啟檔案",
+    "The file should now open on your device. If it doesn't, please check that you have the desktop app installed." : "檔案現在應該可以在您的裝置上開啟。如果打不開，請檢查您是否有安裝桌面應用程式。",
+    "Retry and close" : "重試並關閉",
+    "Open online" : "線上開啟",
+    "Failed to redirect to client" : "重新導向到客戶端失敗",
+    "Open locally" : "在本機開啟",
     "Rename" : "重新命名",
     "Open details" : "開啟詳細資訊",
     "View in folder" : "在資料夾中檢視",
@@ -312,13 +322,6 @@ OC.L10N.register(
     "Files moved successfully" : "檔案移動成功",
     "Conflicts resolution skipped" : "已略過衝突解決",
     "Upload cancelled" : "已取消上傳",
-    "Adding the file extension \"{new}\" may render the file unreadable." : "加入檔案副檔名「{new}」可能會導致檔案無法讀取。",
-    "Removing the file extension \"{old}\" may render the file unreadable." : "移除檔案副檔名「{old}」可能會導致檔案無法讀取。",
-    "Changing the file extension from \"{old}\" to \"{new}\" may render the file unreadable." : "將檔案副檔名從「{old}」改為「{new}」可能會導致檔案無法讀取。",
-    "Change file extension" : "變更檔案副檔名",
-    "Keep {oldextension}" : "保留 {oldextension}",
-    "Use {newextension}" : "使用 {newextension}",
-    "Remove extension" : "移除副檔名",
     "This operation is forbidden" : "此操作被禁止",
     "This directory is unavailable, please check the logs or contact the administrator" : "這個目錄無法取用，請檢查伺服器紀錄檔或聯絡管理員",
     "Storage is temporarily not available" : "儲存空間暫時無法使用",
@@ -328,6 +331,7 @@ OC.L10N.register(
     "_1 file and {folderCount} folder_::_1 file and {folderCount} folders_" : ["1 個檔案與 {folderCount} 個資料夾"],
     "_{fileCount} file and 1 folder_::_{fileCount} files and 1 folder_" : ["{fileCount} 個檔案與 1 個資料夾"],
     "{fileCount} files and {folderCount} folders" : "{fileCount} 個檔案與 {folderCount} 個資料夾",
+    "_(%n hidden)_::_ (%n hidden)_" : ["（%n 個隱藏）"],
     "Filename must not be empty." : "檔案名稱不能為空。",
     "\"{char}\" is not allowed inside a filename." : "檔案名稱中不允許出現「{char}」",
     "\"{segment}\" is a reserved name and not allowed for filenames." : "「{segment}」是保留名稱，不允許用在檔案名稱。",
@@ -347,7 +351,6 @@ OC.L10N.register(
     "List of recently modified files and folders." : "最近修改的檔案與資料夾的清單。",
     "No recently modified files" : "最近無修改檔案",
     "Files and folders you recently modified will show up here." : "您最近修改的檔案與資料夾將會顯示在此處。",
-    "You do not have permission to upload or create files here" : "您無權在此上傳或建立檔案",
     "No entries found in this folder" : "此資料夾中沒有任何項目",
     "Select all" : "全選",
     "Upload too large" : "上傳檔案過大",
@@ -375,6 +378,7 @@ OC.L10N.register(
     "Error when assembling chunks, status code {status}" : "重組檔案片段時出錯，狀態代碼 {status}",
     "Choose target folder" : "選擇目標資料夾",
     "Set reminder" : "設定提醒",
+    "Edit locally" : "在本機編輯",
     "Open" : "開啟",
     "Could not load info for file \"{file}\"" : "無法讀取「{file}」的詳細資料",
     "Details" : "詳細資料",
@@ -405,6 +409,7 @@ OC.L10N.register(
     "_%n file_::_%n files_" : ["%n 個檔案"],
     "{dirs} and {files}" : "{dirs} 和 {files}",
     "_including %n hidden_::_including %n hidden_" : ["包含 %n 個隱藏檔"],
+    "You do not have permission to upload or create files here" : "您無權在此上傳或建立檔案",
     "_Uploading %n file_::_Uploading %n files_" : ["正在上傳 %n 個檔案"],
     "New" : "新增",
     "New file/folder menu" : "新檔案/資料夾選單",
@@ -432,11 +437,14 @@ OC.L10N.register(
     "Upload file" : "上傳檔案",
     "Not favorited" : "未加入至喜愛",
     "An error occurred while trying to update the tags" : "更新標籤時發生錯誤",
+    "You don't have permission to upload or create files here." : "您無權在此上傳或建立檔案。",
     "Storage informations" : "儲存空間資訊",
     "Choose file" : "選擇檔案",
     "Go to the previous folder" : "前往上一個資料夾",
     "Open the files app settings" : "開啟檔案應用程式設定",
     "Unable to change the favourite state of the file" : "無法更改檔案的喜愛狀態",
+    "Edit file locally" : "本機編輯檔案",
+    "Edit online" : "線上編輯",
     "Create new templates folder" : "建立新的範本資料夾",
     "List of favorites files and folders." : "喜愛檔案與資料夾的清單。",
     "Personal Files" : "個人檔案",
@@ -445,6 +453,9 @@ OC.L10N.register(
     "Favored" : "已加入最愛",
     "Favor" : "加入最愛",
     "Not favored" : "未加入最愛",
-    "Filter filenames…" : "篩選檔案名稱……"
+    "Submitting fields…" : "正在遞交欄位……",
+    "Filter filenames…" : "篩選檔案名稱……",
+    "{count} files could not be converted" : "{count} 個檔案無法轉換",
+    "{count} files successfully converted" : "{count} 個檔案成功轉換"
 },
 "nplurals=1; plural=0;");
