@@ -113,7 +113,6 @@ OC.L10N.register(
     "Personal info" : "اطّلاعات شخصی",
     "Mobile & desktop" : "همراه و میزکار",
     "Email server" : "سرور ایمیل",
-    "Security & setup warnings" : "اخطارهای نصب و امنیتی",
     "Background jobs" : "کارهای پس‌زمینه",
     "Unlimited" : "نامحدود",
     "Verifying" : "تآیید کردن",
@@ -135,14 +134,15 @@ OC.L10N.register(
     "Profile information" : "اطلاعات نمایه",
     "Nextcloud settings" : "تنظیمات نکست کلود",
     "Task:" : "Task:",
+    "Enable" : "فعال",
     "Machine translation" : "Machine translation",
     "Machine translation can be implemented by different apps. Here you can define the precedence of the machine translation apps you have installed at the moment." : "Machine translation can be implemented by different apps. Here you can define the precedence of the machine translation apps you have installed at the moment.",
     "Image generation" : "Image generation",
     "Text processing" : "Text processing",
     "Text processing tasks can be implemented by different apps. Here you can set which app should be used for which task." : "Text processing tasks can be implemented by different apps. Here you can set which app should be used for which task.",
     "Here you can decide which group can access certain sections of the administration settings." : "Here you can decide which group can access certain sections of the administration settings.",
-    "None" : "هیچ‌کدام",
     "Unable to modify setting" : "Unable to modify setting",
+    "None" : "هیچ‌کدام",
     "Allow apps to use the Share API" : "اجازه ی برنامه ها برای استفاده از API اشتراک گذاری",
     "Allow resharing" : "مجوز اشتراک گذاری مجدد",
     "Allow sharing with groups" : "اشتراک گذاری با گروه ها مجاز است",
@@ -151,7 +151,6 @@ OC.L10N.register(
     "Allow public uploads" : "اجازه بارگذاری عمومی",
     "Always ask for a password" : "رمز عبور را همیشه بپرسید.",
     "Enforce password protection" : "اجبار برای محافظت توسط رمز عبور",
-    "Set default expiration date for shares" : "تاریخ انقضا پیش فرض را برای اشتراک گذاری تعیین کنید",
     "Enforce expiration date" : "اعمال تاریخ اتمام اشتراک گذاری",
     "Set default expiration date for shares to other servers" : "Set default expiration date for shares to other servers",
     "If autocompletion \"same group\" and \"phone number integration\" are enabled a match in either is enough to show the user." : "If autocompletion \"same group\" and \"phone number integration\" are enabled a match in either is enough to show the user.",
@@ -170,10 +169,10 @@ OC.L10N.register(
     "Save changes" : "ذخیرهٔ تغییرات",
     "Update to {update}" : "به‌روز رسانی به {update} ",
     "Remove" : "برداشتن",
-    "Disable" : "غیرفعال",
     "Featured" : "برگزیده",
     "This app is supported via your current Nextcloud subscription." : "این کاره از طریق اشتراک فعلی نکست کلودتان پشتیبانی می شود.",
     "Featured apps are developed by and within the community. They offer central functionality and are ready for production use." : "برنامه‌های برگزیده توسط و در داخل جامعه توسعه داده می‌شوند. این برنامه‌ها، عملکردهای مرکزی را ارائه می‌دهند و برای استفاده نهایی آماده هستند.",
+    "Disable all" : "از کار انداختن همه",
     "All apps are up-to-date." : "تمامی کاره‌ها به‌روزند.",
     "Icon" : "Icon",
     "Name" : "نام",
@@ -182,11 +181,21 @@ OC.L10N.register(
     "Actions" : "کنش‌ها",
     "Results from other categories" : "نتایج از دیگر دسته‌ها",
     "No apps found for your version" : "هیچ برنامه‌ای برای نسخه‌ی شما یافت نشد",
-    "Disable all" : "از کار انداختن همه",
     "_%n app has an update available_::_%n apps have an update available_" : ["۱ کاره به‌روز رسانی دارد","%n کاره به‌روز رسانی دارند"],
     "_Update_::_Update all_" : ["به‌روز رسانی","به‌روز رسانی همه"],
+    "Group name" : "نام گروه",
+    "Loading groups…" : "Loading groups…",
     "Loading" : "Loading",
+    "Daemon" : "فرایندهای پس زمینه",
+    "Type" : "نوع",
+    "Learn more" : "بیشتر بدانید",
+    "Confirm" : "تأیید",
+    "Cancel" : "منصرف شدن",
     "Description" : "شرح",
+    "View in store" : "نمایش در فروشگاه",
+    "Visit website" : "سر زدن به پایگاه وب",
+    "Admin documentation" : "مستندات مدیر",
+    "Developer documentation" : "مستندات توسعه‌دهندگان",
     "Details" : "جزییات",
     "All" : "همه",
     "Limit app usage to groups" : "محدودیت استفاده از کاره به گروه‌ها",
@@ -199,15 +208,18 @@ OC.L10N.register(
     "Categories" : "دسته‌ها",
     "Resources" : "منابع",
     "Documentation" : "مستندسازی",
+    "Interact" : "تعامل",
     "Report a bug" : "گزارش یک خطا",
     "Request feature" : "درخواست ویژگی",
     "Ask questions or discuss" : "پرسش یا بحث",
     "Rate" : "رتبه‌بندی",
-    "View in store" : "نمایش در فروشگاه",
-    "Visit website" : "سر زدن به پایگاه وب",
-    "Admin documentation" : "مستندات مدیر",
-    "Developer documentation" : "مستندات توسعه‌دهندگان",
     "Changelog" : "تغییر",
+    "Google Chrome for Android" : "کروم گوگل برای اندروید",
+    "{productName} iOS app" : "کارهٔ iOS {productName}",
+    "{productName} Android app" : "کارهٔ اندرویدی {productName}",
+    "{productName} Talk for iOS" : "صحبت {productName} برای iOS",
+    "{productName} Talk for Android" : "صحبت {productName} برای اندروید",
+    "This session" : "این نشست",
     "Marked for remote wipe" : "علامت خورده برای زودون دوردست",
     "Device settings" : "تنظیمات افزاره",
     "Allow filesystem access" : "اجازهٔ دسترسی به سامانه‌پرونده",
@@ -215,57 +227,55 @@ OC.L10N.register(
     "Revoke" : "لغو",
     "Wipe device" : "حذف دستگاه",
     "Revoking this token might prevent the wiping of your device if it has not started the wipe yet." : "Revoking this token might prevent the wiping of your device if it has not started the wipe yet.",
-    "Google Chrome for Android" : "کروم گوگل برای اندروید",
-    "{productName} iOS app" : "کارهٔ iOS {productName}",
-    "{productName} Android app" : "کارهٔ اندرویدی {productName}",
-    "{productName} Talk for iOS" : "صحبت {productName} برای iOS",
-    "{productName} Talk for Android" : "صحبت {productName} برای اندروید",
-    "This session" : "این نشست",
     "Device" : "افزاره",
     "Last activity" : "آخرین فعّالیت",
     "Devices & sessions" : "دستگاه ها و نشست ها",
     "Web, desktop and mobile clients currently logged in to your account." : "لیست دستگاه ها و نشست های فعال وارد شده با اکانت شما",
+    "Error while creating device token" : "هنگام ایجاد نشانه وسیله خطایی رخ داد",
     "App name" : "نام برنامه",
     "Create new app password" : "ساختن رمزعبور برنامه جدید ",
-    "Error while creating device token" : "هنگام ایجاد نشانه وسیله خطایی رخ داد",
+    "Could not copy app password. Please copy it manually." : "نمی توان رمزعبور برنامه را کپی کرد. لطفاً آن را به صورت دستی کپی کنید.",
     "Login" : "ورود",
     "Password" : "گذرواژه",
     "Show QR code for mobile apps" : "نمایش کد QR برای برنامه های تلفن همراه",
-    "Could not copy app password. Please copy it manually." : "نمی توان رمزعبور برنامه را کپی کرد. لطفاً آن را به صورت دستی کپی کنید.",
+    "Use system cron service to call the cron.php file every 5 minutes." : "برای تماس با پرونده cron.php هر 5 دقیقه یکبار از سرویس cron system استفاده کنید.",
+    "The PHP POSIX extension is required. See {linkstart}PHP documentation{linkend} for more details." : "The PHP POSIX extension is required. See {linkstart}PHP documentation{linkend} for more details.",
+    "Unable to update background job mode" : "ناتوان در به‌روز رسانی حالت کار پس‌زمینه",
     "For the server to work properly, it's important to configure background jobs correctly. Cron is the recommended setting. Please see the documentation for more information." : "For the server to work properly, it's important to configure background jobs correctly. Cron is the recommended setting. Please see the documentation for more information.",
     "Last job execution ran {time}. Something seems wrong." : "آخرین کار در {time} اجرا شد. به نظر چیزی اشتباه است.",
-    "Last job ran {relativeTime}." : "آخرین کار در {time} اجرا شد.",
+    "Last job ran {relativeTime}." : "آخرین کار در {relativeTime} اجرا شد.",
     "Background job did not run yet!" : "هنوز کار پس‌زمینه‌ای اجار نشده!",
     "AJAX" : "ای‌جکس",
     "Webcron" : "وب‌کرون",
     "Cron (Recommended)" : "کرون (پیشنهادی)",
-    "Use system cron service to call the cron.php file every 5 minutes." : "برای تماس با پرونده cron.php هر 5 دقیقه یکبار از سرویس cron system استفاده کنید.",
-    "The PHP POSIX extension is required. See {linkstart}PHP documentation{linkend} for more details." : "The PHP POSIX extension is required. See {linkstart}PHP documentation{linkend} for more details.",
-    "Unable to update background job mode" : "ناتوان در به‌روز رسانی حالت کار پس‌زمینه",
-    "Profile" : "نمایه",
-    "Enable" : "فعال",
     "Unable to update profile default setting" : "ناتوان در به‌روز رسانی تنظیمات پیش‌گزیدهٔ نمایه",
+    "Profile" : "نمایه",
+    "Unable to update server side encryption config" : "Unable to update server side encryption config",
     "Server-side encryption" : "رمزگذاری سمت سرور",
     "Server-side encryption makes it possible to encrypt files which are uploaded to this server. This comes with limitations like a performance penalty, so enable this only if needed." : "\"رمزگذاری سمت سرور\" امکان رمزگذاری پرونده های آپلود شده در این سرور را امکان پذیر می کند. که با محدودیت هایی مانند مجازات عملکرد همراه است ، بنابراین در صورت لزوم فعال کنید.",
     "Enable server-side encryption" : "فعال‌سازی رمزگذاری سمت-سرور",
+    "No encryption module loaded, please enable an encryption module in the app menu." : "هیچ ماژول رمزگذاری‌ای بارگذاری نشده است، لطفا ماژول رمز‌گذاری را در منو برنامه فعال کنید.",
+    "Select default encryption module:" : "انتخاب ماژول پیش‌فرض رمزگذاری:",
+    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run {command}" : "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run {command}",
+    "Enable encryption" : "فعال کردن رمزگذاری",
     "Please read carefully before activating server-side encryption:" : "Please read carefully before activating server-side encryption:",
     "Once encryption is enabled, all files uploaded to the server from that point forward will be encrypted at rest on the server. It will only be possible to disable encryption at a later date if the active encryption module supports that function, and all pre-conditions (e.g. setting a recover key) are met." : "پس از فعال سازی رمزگذاری ، تمام پرونده های بارگذاری شده از آن نقطه به سرور بارگیری می شوند و در حالت آماده به کار روی سرور رمزگذاری می شوند. غیرفعال کردن رمزگذاری در صورتی که ماژول رمزگذاری فعال از آن عملکرد پشتیبانی کند، در تاریخ بعد امکان پذیر است و کلیه پیش شرط ها (به عنوان مثال تنظیم کلید بازیابی) برآورده می شوند.",
     "Encryption alone does not guarantee security of the system. Please see documentation for more information about how the encryption app works, and the supported use cases." : "رمزگذاری به تنهایی امنیت سیستم را تضمین نمی کند. لطفاً برای اطلاعات بیشتر درباره چگونگی عملکرد برنامه رمزگذاری و موارد استفاده از پشتیبانی ، به اسناد مراجعه کنید.",
     "Be aware that encryption always increases the file size." : "توجه داشته باشید که همواره رمزگذاری حجم فایل را افزایش خواهد داد.",
     "It is always good to create regular backups of your data, in case of encryption make sure to backup the encryption keys along with your data." : "همیشه خوب است که از داده های خود نسخه پشتیبان تهیه کنید ، در صورت رمزگذاری مطمئن شوید که از کلیدهای رمزنگاری به همراه داده خود نسخه پشتیبان تهیه کنید.",
     "This is the final warning: Do you really want to enable encryption?" : "این آخرین اخطار است: آیا می‌خواهید رمزگذاری را فعال کنید ؟",
-    "No encryption module loaded, please enable an encryption module in the app menu." : "هیچ ماژول رمزگذاری‌ای بارگذاری نشده است، لطفا ماژول رمز‌گذاری را در منو برنامه فعال کنید.",
-    "Select default encryption module:" : "انتخاب ماژول پیش‌فرض رمزگذاری:",
-    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run {command}" : "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run {command}",
-    "Unable to update server side encryption config" : "Unable to update server side encryption config",
-    "Cancel" : "منصرف شدن",
-    "Confirm" : "تأیید",
     "Submit" : "ارسال",
     "Rename group" : "Rename group",
     "Remove group" : "برداشتن گروه",
     "Current password" : "گذرواژه کنونی",
     "New password" : "گذرواژه جدید",
     "Change password" : "تغییر گذر واژه",
+    "Choose your profile picture" : "عکس نمایهٔ خود را انتخاب کنید",
+    "Please select a valid png or jpg file" : "لطفاً یک فایل png یا jpg معتبر انتخاب کنید",
+    "Error setting profile picture" : "خطا در تنظیم عکس نمایه",
+    "Error cropping profile picture" : "خطا در برش عکس نمایه",
+    "Error saving profile picture" : "خطا در ذخیره تصویر نمایه",
+    "Error removing profile picture" : "خطا در حذف عکس نمایه",
     "Your profile picture" : "نگارهٔ نمایه‌تان",
     "Upload profile picture" : "بارگذاری نگارهٔ نمایه",
     "Choose profile picture from Files" : "تصویر نمایه‌تان را از پرونده‌ها انتخاب کنید",
@@ -274,18 +284,8 @@ OC.L10N.register(
     "Picture provided by original account" : "نگاره فراهم شده به دست حساب اصلی",
     "Set as profile picture" : "به عنوان عکس نمایه تنظیم کنید",
     "Please note that it can take up to 24 hours for your profile picture to be updated everywhere." : "لطفاً توجه داشته باشید که ممکن است تا 24 ساعت طول بکشد تا عکس نمایه شما در همه جا به روز شود.",
-    "Choose your profile picture" : "عکس نمایهٔ خود را انتخاب کنید",
-    "Please select a valid png or jpg file" : "لطفاً یک فایل png یا jpg معتبر انتخاب کنید",
-    "Error setting profile picture" : "خطا در تنظیم عکس نمایه",
-    "Error cropping profile picture" : "خطا در برش عکس نمایه",
-    "Error saving profile picture" : "خطا در ذخیره تصویر نمایه",
-    "Error removing profile picture" : "خطا در حذف عکس نمایه",
-    "Your biography" : "بیوگرافی شما",
     "You are a member of the following groups:" : "عضوی از گروه‌های زیر هستید:",
-    "You are using <strong>{usage}</strong>" : "فضای مورد استفاده: <strong>{usage}</strong>",
-    "You are using <strong>{usage}</strong> of <strong>{totalSpace}</strong> (<strong>{usageRelative}%</strong>)" : "شما در حال استفادهٔ <strong>{usage}</strong> از <strong>{totalSpace}</strong> (<strong>{usageRelative}٪</strong>) فضا هستید",
     "Your full name" : "Your full name",
-    "Primary email for password reset and notifications" : "ایمیل اصلی برای بازیابی رمز عبور و دریافت اعلان ها",
     "Email options" : "Email options",
     "Remove primary email" : "Remove primary email",
     "Delete email" : "Delete email",
@@ -298,14 +298,15 @@ OC.L10N.register(
     "Unable to add additional email address" : "Unable to add additional email address",
     "Unable to update additional email address" : "Unable to update additional email address",
     "Unable to delete additional email address" : "Unable to delete additional email address",
+    "Primary email for password reset and notifications" : "ایمیل اصلی برای بازیابی رمز عبور و دریافت اعلان ها",
     "No email address set" : "آدرس‌ایمیلی تنظیم نشده است",
     "Your handle" : "Your handle",
     "Your headline" : "عنوان سرصفحه",
-    "Help translate" : "به ترجمه آن کمک کنید",
     "Unable to update language" : "Unable to update language",
+    "Help translate" : "به ترجمه آن کمک کنید",
     "No language set" : "زبانی تنظیم نشده است.",
-    "Week starts on {firstDayOfWeek}" : "Week starts on {firstDayOfWeek}",
     "Unable to update locale" : "Unable to update locale",
+    "Week starts on {firstDayOfWeek}" : "Week starts on {firstDayOfWeek}",
     "No locale set" : "تنظیمات locale انجام نشده است",
     "Your city" : "شهر شما",
     "Your organisation" : "نام سازمان",
@@ -315,8 +316,8 @@ OC.L10N.register(
     "Unable to update visibility of {displayId}" : "Unable to update visibility of {displayId}",
     "Your role" : "نقش شما",
     "Your website" : "وبسایت شما",
-    "No {property} set" : "No {property} set",
     "Unable to update {property}" : "Unable to update {property}",
+    "No {property} set" : "No {property} set",
     "Change scope level of {property}, current scope is {scope}" : "Change scope level of {property}, current scope is {scope}",
     "Unable to update federation scope of the primary {property}" : "Unable to update federation scope of the primary {property}",
     "Unable to update federation scope of additional {property}" : "Unable to update federation scope of additional {property}",
@@ -326,11 +327,12 @@ OC.L10N.register(
     "Change" : "تغییر",
     "Delete" : "حذف",
     "Reshare" : "بازهم‌رسانی",
-    "No accounts" : "حسابی وجود ندارد",
     "Default language" : "زبان پیش فرض",
     "Common languages" : "زبانهای رایج",
     "Other languages" : "Other languages",
     "Password change is disabled because the master key is disabled" : "تغییر رمز غیرفعال شده است زیرا کلید اصلی غیرفعال شده است",
+    "No accounts" : "حسابی وجود ندارد",
+    "Manager" : "Manager",
     "Display name" : "نمایش نام",
     "Either password or email is required" : "Either password or email is required",
     "Password (required)" : "Password (required)",
@@ -339,17 +341,17 @@ OC.L10N.register(
     "Quota" : "سهم",
     "Language" : "زبان",
     "Set default language" : "Set default language",
-    "Manager" : "Manager",
+    "_{userCount} account …_::_{userCount} accounts …_" : ["{userCount} حساب ...","{userCount} حساب ..."],
+    "_{userCount} account_::_{userCount} accounts_" : ["{userCount} حساب","{userCount} حساب"],
     "Total rows summary" : "خلاصه کل ردیف ها",
     "Scroll to load more rows" : "Scroll to load more rows",
+    "Password or insufficient permissions message" : "Password or insufficient permissions message",
     "Avatar" : "آواتار",
     "Account name" : "Account name",
     "Group admin for" : "مدیر گروه برای",
     "Storage location" : "محل ذخیره سازی",
     "Last login" : "آخرین ورود",
     "Account actions" : "اقدامات حساب",
-    "Password or insufficient permissions message" : "Password or insufficient permissions message",
-    "Set the language" : "Set the language",
     "{size} used" : "{size} مورد استفاده",
     "Resend welcome email" : "ارسال ایمیل خوش آمدید",
     "In case of lost device or exiting the organization, this can remotely wipe the Nextcloud data from all devices associated with {userid}. Only works if the devices are connected to the internet." : "در صورت گم شدن دستگاه یا خارج شدن از سازمان ، می توانید داده های نکست کلود را از راه دور از بین همه دستگاه های مرتبط با  {userid} آن پاک کنید. فقط در صورت اتصال دستگاه ها به اینترنت کار می کند.",
@@ -363,6 +365,7 @@ OC.L10N.register(
     "Password was successfully changed" : "Password was successfully changed",
     "Email was successfully changed" : "Email was successfully changed",
     "Welcome mail sent!" : "نامه خوش آمديد ارسال شد",
+    "Set the language" : "Set the language",
     "Done" : "انجام شد",
     "Edit" : "ویرایش",
     "Visibility" : "Visibility",
@@ -374,11 +377,11 @@ OC.L10N.register(
     "Defaults" : "Defaults",
     "Default quota" : "سهمیه پیش فرض",
     "Select default quota" : "سهمیه پیش فرض را انتخاب کنید",
+    "Server error while trying to complete WebAuthn device registration" : "Server error while trying to complete WebAuthn device registration",
     "Passwordless authentication requires a secure connection." : "Passwordless authentication requires a secure connection.",
     "Add WebAuthn device" : "Add WebAuthn device",
     "Please authorize your WebAuthn device." : "Please authorize your WebAuthn device.",
     "Adding your device …" : "Adding your device …",
-    "Server error while trying to complete WebAuthn device registration" : "Server error while trying to complete WebAuthn device registration",
     "Unnamed device" : "Unnamed device",
     "Passwordless Authentication" : "Passwordless Authentication",
     "Set up your account for passwordless authentication following the FIDO2 standard." : "Set up your account for passwordless authentication following the FIDO2 standard.",
@@ -389,7 +392,6 @@ OC.L10N.register(
     "You need to enable the File sharing App." : "You need to enable the File sharing App.",
     "All accounts" : "همهٔ حساب‌ها",
     "Admins" : "مدیران",
-    "Group name" : "نام گروه",
     "Sending…" : "در حال ارسال",
     "Email sent" : "ایمیل ارسال شد",
     "Location" : "مکان",
@@ -397,11 +399,11 @@ OC.L10N.register(
     "About" : "درباره",
     "Full name" : "نام کامل",
     "Additional email" : "Additional email",
+    "Fediverse (e.g. Mastodon)" : "Fediverse (e.g. Mastodon)",
     "Headline" : "عنوان",
     "Organisation" : "سازمان",
     "Phone number" : "شماره تلفن",
     "Role" : "نقش",
-    "Fediverse (e.g. Mastodon)" : "Fediverse (e.g. Mastodon)",
     "Website" : "وب‌ سایت",
     "Profile visibility" : "امکان دیده شدن پروفایل",
     "Locale" : "محل",
@@ -417,13 +419,15 @@ OC.L10N.register(
     "Show to logged in accounts only" : "فقط به حساب‌هایی که وارد شده‌اند نمایش یابد",
     "Hide" : "پنهان کردن",
     "Download and enable" : "بارگیری و فعال سازی",
+    "Disable" : "غیرفعال",
     "Allow untested app" : "Allow untested app",
     "The app will be downloaded from the App Store" : "The app will be downloaded from the App Store",
     "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "این برنامه مطابق با نسخه نکست کلود شما مشخص نشده است. اگر ادامه بدهید همچنان می توانید برنامه را نصب کنید. توجه داشته باشید که برنامه ممکن است مطابق آنچه انتظار می رود کار نکند.",
+    "Unknown" : "ناشناخته",
     "Never" : "هرگز",
     "An error occurred during the request. Unable to proceed." : "An error occurred during the request. Unable to proceed.",
-    "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "برنامه فعال شده است اما باید به روز شود. شما پس از 5 ثانیه به صفحه بروزرسانی هدایت می شوید.",
     "Error: This app cannot be enabled because it makes the server unstable" : "Error: This app cannot be enabled because it makes the server unstable",
+    "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "برنامه فعال شده است اما باید به روز شود. شما پس از 5 ثانیه به صفحه بروزرسانی هدایت می شوید.",
     "Do you really want to wipe your data from this device?" : "واقعاً می خواهید داده‌هایتان را از این افزاره بزدایید؟",
     "Confirm wipe" : "تأیید زودن",
     "Error while wiping the device with the token" : "هنگام پاک کردن وسیله با نشانه خطا رخ داد",
@@ -451,6 +455,7 @@ OC.L10N.register(
     "SMTP Password" : "رمز عبور SMTP",
     "Save" : "ذخیره",
     "Test and verify email settings" : "Test and verify email settings",
+    "Security & setup warnings" : "اخطارهای نصب و امنیتی",
     "It's important for the security and performance of your instance that everything is configured correctly. To help you with that we are doing some automatic checks. Please see the linked documentation for more information." : "برای امنیت و عملکرد نمونه شما، مهم است که همه چیز به درستی پیکربندی شده باشد. برای کمک به شما در این مورد ، ما برخی از بررسی های خودکار را انجام می دهیم. لطفا برای اطلاعات بیشتر به مستندات مرتبط مراجعه کنید.",
     "All checks passed." : "تمامی موارد با موفقیت چک شدند.",
     "There are some errors regarding your setup." : "برخی از خطاها در مورد راه اندازی شما وجود دارد",
@@ -461,22 +466,12 @@ OC.L10N.register(
     "Reasons to use Nextcloud in your organization" : "دلایلی برای استفاده از نکست‌کلود در سازمان شما",
     "Developed by the {communityopen}Nextcloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}AGPL{linkclose}." : "توسعه یافته توسط {communityopen} انجمن نکست کلود {linkclose}، {githubopen} کد منبع {linkclose} تحت مجوز {licenseopen}AGPL{linkclose}است. ",
     "Like our Facebook page" : "پسندیدن صفحه فیس بوک ما",
-    "Follow us on Twitter" : "ما را در توییتر دنبال کنید",
     "Follow us on Mastodon" : "ما را در ماستودون دنبال کنید",
     "Check out our blog" : "وبلاگ ما را بررسی کنید",
     "Subscribe to our newsletter" : "مشترک شدن در خبرنامه ما",
     "This community release of Nextcloud is unsupported and instant notifications are unavailable." : "This community release of Nextcloud is unsupported and instant notifications are unavailable.",
     "Use a second factor besides your password to increase security for your account." : "برای افزایش امنیت حساب کاربری خود ، از یک عامل دوم علاوه بر رمز عبور خود استفاده کنید.",
     "If you use third party applications to connect to Nextcloud, please make sure to create and configure an app password for each before enabling second factor authentication." : "If you use third party applications to connect to Nextcloud, please make sure to create and configure an app password for each before enabling second factor authentication.",
-    "No user supplied" : "هیچ کاربری تعریف نشده است",
-    "Please provide an admin recovery password; otherwise, all user data will be lost." : "لطفاً رمز عبور بازیابی مدیر را ارائه دهید. در غیر این صورت ، تمام داده های کاربر از بین می رود.",
-    "Backend does not support password change, but the user's encryption key was updated." : " سرور از تغییرات گذرواژه پشتیبانی نمی کند، اما کلید رمزگذاری کاربر به روز شد.",
-    "You need to set your user email before being able to send test emails. Go to %s for that." : "You need to set your user email before being able to send test emails. Go to %s for that.",
-    "Invalid user" : "کاربر نامعتبر",
-    "Your username is: %s" : "نام کاربری شما %s هست.",
-    "Logged in user must be a subadmin" : "ورود به سیستم کاربر باید زیرمجموعه باشد",
-    "A background job is pending that checks for user imported SSL certificates. Please check back later." : "A background job is pending that checks for user imported SSL certificates. Please check back later.",
-    "There are some user imported SSL certificates present, that are not used anymore with Nextcloud 21. They can be imported on the command line via \"occ security:certificates:import\" command. Their paths inside the data directory are shown below." : "There are some user imported SSL certificates present, that are not used anymore with Nextcloud 21. They can be imported on the command line via \"occ security:certificates:import\" command. Their paths inside the data directory are shown below.",
     "The database is missing some indexes. Due to the fact that adding indexes on big tables could take some time they were not added automatically. By running \"occ db:add-missing-indices\" those missing indexes could be added manually while the instance keeps running. Once the indexes are added queries to those tables are usually much faster." : "The database is missing some indexes. Due to the fact that adding indexes on big tables could take some time they were not added automatically. By running \"occ db:add-missing-indices\" those missing indexes could be added manually while the instance keeps running. Once the indexes are added queries to those tables are usually much faster.",
     "MariaDB version \"%s\" is used. Nextcloud 21 and higher do not support this version and require MariaDB 10.2 or higher." : "MariaDB version \"%s\" is used. Nextcloud 21 and higher do not support this version and require MariaDB 10.2 or higher.",
     "MySQL version \"%s\" is used. Nextcloud 21 and higher do not support this version and require MySQL 8.0 or MariaDB 10.2 or higher." : "MySQL version \"%s\" is used. Nextcloud 21 and higher do not support this version and require MySQL 8.0 or MariaDB 10.2 or higher.",
@@ -485,22 +480,14 @@ OC.L10N.register(
     "Speech-To-Text can be implemented by different apps. Here you can set which app should be used." : "Speech-To-Text can be implemented by different apps. Here you can set which app should be used.",
     "None of your currently installed apps provide Speech-To-Text functionality" : "None of your currently installed apps provide Speech-To-Text functionality",
     "None of your currently installed apps provide Text processing functionality" : "None of your currently installed apps provide Text processing functionality",
-    "Exclude groups from sharing" : "مستثنی شدن گروه ها از اشتراک گذاری",
-    "These groups will still be able to receive shares, but not to initiate them." : "این گروه ها هنوز هم می توانند سهم دریافت کنند ، اما نه آنها را شروع کنند.",
+    "Set default expiration date for shares" : "تاریخ انقضا پیش فرض را برای اشتراک گذاری تعیین کنید",
     "Allow username autocompletion in share dialog and allow access to the system address book" : "Allow username autocompletion in share dialog and allow access to the system address book",
-    "Two-factor authentication can be enforced for all users and specific groups. If they do not have a two-factor provider configured, they will be unable to log into the system." : "Two-factor authentication can be enforced for all users and specific groups. If they do not have a two-factor provider configured, they will be unable to log into the system.",
-    "When groups are selected/excluded, they use the following logic to determine if a user has 2FA enforced: If no groups are selected, 2FA is enabled for everyone except members of the excluded groups. If groups are selected, 2FA is enabled for all members of these. If a user is both in a selected and excluded group, the selected takes precedence and 2FA is enforced." : "هنگامی که گروه ها انتخاب و حذف شدند ، از این منطق استفاده می کنند تا مشخص شود آیا کاربر 2FA اجباری دارد: اگر هیچ گروه انتخاب نشده باشند ، 2FA برای همه غیر از اعضای گروه های محروم امکان پذیر است. در صورت انتخاب گروه ها ، 2FA برای همه اعضای این گروه فعال است. اگر کاربر هر دو در یک گروه منتخب و مستثنی باشد ، انتخاب شده دارای اولویت است و 2FA اجرا می شود.",
-    "{license}-licensed" : "دارای مجوز- {license}",
-    "Username" : "نام کاربری",
-    "Execute one task with each page loaded. Use case: Single user instance." : "اجرای یک وظیفه با هر بار شدن صفحه. مناسب نمونه‌های تک کاربره.",
-    "cron.php is registered at a webcron service to call cron.php every 5 minutes over HTTP. Use case: Very small instance (1–5 users depending on the usage)." : "پروندهٔ cron.php ثبت شده در یک خدمت webcron برای فراخوانی هر ۵ دقیقه یک بار روی HTTP. مناسب برای نمونه‌های بسیار کوچک ( تا ۵ کاربر بسته به استفاده).",
-    "The cron.php needs to be executed by the system user \"{user}\"." : "پروندهٔ cron.php باید به دست کاربر سامانه‌ای {user} قابل اجرا باشد.",
-    "Enable or disable profile by default for new users." : "به یا از کار انداختن نمایه برای کاربران جدید به صورت پیش‌گزیده.",
-    "Additional emails" : "Additional emails",
-    "Enable Profile" : "فعال کردن پروفایل",
-    "No users" : "No users",
-    "Loading users …" : "Loading users …",
-    "List of users. This list is not fully rendered for performance reasons. The users will be rendered as you navigate through the list." : "List of users. This list is not fully rendered for performance reasons. The users will be rendered as you navigate through the list.",
+    "Your biography" : "بیوگرافی شما",
+    "You are using <strong>{usage}</strong>" : "فضای مورد استفاده: <strong>{usage}</strong>",
+    "You are using <strong>{usage}</strong> of <strong>{totalSpace}</strong> (<strong>{usageRelative}%</strong>)" : "شما در حال استفادهٔ <strong>{usage}</strong> از <strong>{totalSpace}</strong> (<strong>{usageRelative}٪</strong>) فضا هستید",
+    "Set user manager" : "Set user manager",
+    "Username will be autogenerated" : "Username will be autogenerated",
+    "Username (required)" : "Username (required)",
     "New user" : "کاربر جدید",
     "Groups (required)" : "Groups (required)",
     "Set user groups" : "Set user groups",
@@ -508,35 +495,16 @@ OC.L10N.register(
     "Set user as admin for …" : "Set user as admin for …",
     "Set user quota" : "Set user quota",
     "Add new user" : "Add new user",
-    "Set user manager" : "Set user manager",
-    "Username will be autogenerated" : "Username will be autogenerated",
-    "Username (required)" : "Username (required)",
+    "_{userCount} user …_::_{userCount} users …_" : ["{userCount} user …","{userCount} users …"],
+    "_{userCount} user_::_{userCount} users_" : ["{userCount} user","{userCount} users"],
+    "Loading users …" : "Loading users …",
+    "Username" : "نام کاربری",
     "User backend" : "پشتیبان کاربر",
     "User actions" : "User actions",
-    "Loading user …" : "Loading user …",
-    "You do not have permissions to see the details of this user" : "شما مجوز دیدن جزئیات این کاربر را ندارید",
     "Add user to group" : "Add user to group",
-    "Set user as admin for" : "کاربر را به عنوان مدیر تنظیم کنید",
-    "Select user quota" : "سهمیه کاربر را انتخاب کنید",
-    "Delete user" : "حذف کردن کاربر",
-    "Wipe all devices" : "همه دستگاه ها را پاک کنید.",
-    "Disable user" : "غیرفعال کردن کاربر",
-    "Enable user" : "کاربر را فعال کنید",
-    "Failed to update user manager" : "Failed to update user manager",
-    "Toggle user actions menu" : "Toggle user actions menu",
-    "User management settings" : "User management settings",
-    "Show user backend" : "نمایش پس زمینه کاربر",
-    "Send welcome email to new users" : "Send welcome email to new users",
-    "Name your device" : "Name your device",
     "Server error while trying to add WebAuthn device" : "Server error while trying to add WebAuthn device",
-    "by {author}\n{license}" : "by {author}\n{license}",
-    "Active users" : "کاربران فعال",
-    "Disabled users" : "کاربران غیرفعال شده است",
-    "Not available as federation has been disabled for your account, contact your system administrator if you have any questions" : "Not available as federation has been disabled for your account, contact your system administrator if you have any questions",
-    "Not available as publishing user specific data to the lookup server is not allowed, contact your system administrator if you have any questions" : "Not available as publishing user specific data to the lookup server is not allowed, contact your system administrator if you have any questions",
-    "Show to logged in users only" : "نمایش فقط برای کاربران وارد شده به سامانه",
-    "Nextcloud help resources" : "منابع راهنمای نکست‌کلود",
-    "SMTP Username" : "نام کاربری SMTP",
-    "Active accounts" : "حساب‌های فعال"
+    "Name your device" : "Name your device",
+    "Active accounts" : "حساب‌های فعال",
+    "Follow us on Twitter" : "ما را در توییتر دنبال کنید"
 },
 "nplurals=2; plural=(n > 1);");
