@@ -27,15 +27,21 @@ OC.L10N.register(
     "Could not complete login" : "Nepavyko užbaigti prisijungimo",
     "Your login token is invalid or has expired" : "Jūsų prieigos raktas yra neteisingas arba pasibaigė jo galiojimo laikas",
     "Login" : "Prisijungti",
+    "Unsupported email length (>255)" : "Nepalaikomas el. pašto žinutės ilgis (>255)",
     "Password reset is disabled" : "Slaptažodžio atstatymas išjungtas",
     "Could not reset password because the token is expired" : "Nepavyko atstatyti slaptažodžio, nes prieigos raktas nebegalioja",
     "Could not reset password because the token is invalid" : "Nepavyko atstatyti slaptažodžio, nes prieigos raktas yra neteisingas",
+    "Password is too long. Maximum allowed length is 469 characters." : "Slaptažodis per ilgas. Didžiausias leistinas ilgis yra 469 simboliai.",
     "%s password reset" : "%s slaptažodžio atstatymas",
     "Password reset" : "Slaptažodžio atstatymas",
     "Click the following button to reset your password. If you have not requested the password reset, then ignore this email." : "Paspauskite mygtuką slaptažodžio atkūrimui. Jei slaptažodžio atkūrimas nėra reikalingas, ignoruokite šį laišką.",
     "Click the following link to reset your password. If you have not requested the password reset, then ignore this email." : "Paspauskite nuorodą slaptažodžio atkūrimui. Jei slaptažodžio atkūrimas nėra reikalingas, ignoruokite šį laišką.",
     "Reset your password" : "Atkurkite savo slaptažodį",
+    "Task not found" : "Užduotis nerasta",
     "Internal error" : "Vidinė klaida",
+    "Not found" : "Nerasta",
+    "Bad request" : "Bloga užklausa",
+    "Image not found" : "Paveikslėlis nerastas",
     "Could not detect language" : "Nepavyko aptikti kalbos",
     "Unable to translate" : "Nepavyko išversti",
     "Nextcloud Server" : "Nextcloud serveris",
@@ -51,6 +57,7 @@ OC.L10N.register(
     "Maintenance mode is kept active" : "Techninės priežiūros veiksena yra aktyvi",
     "Updating database schema" : "Atnaujinama duomenų bazės struktūra",
     "Updated database" : "Atnaujinta duomenų bazė",
+    "Update app \"%s\" from App Store" : "Atnaujinkite programą \"%s\" iš „App Store“. ",
     "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "Tikrinama ar %s duomenų bazės struktūra gali būti atnaujinta (priklausomai nuo duomenų bazės dydžio, tai gali ilgai užtrukti)",
     "Updated \"%1$s\" to %2$s" : "Atnaujinta „%1$s“ į %2$s",
     "Set log level to debug" : "Žurnalo išvesties lygis nustatytas į derinimo",
@@ -76,43 +83,67 @@ OC.L10N.register(
     "Please reload the page." : "Prašome įkelti puslapį iš naujo.",
     "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "Atnaujinimas buvo nesėkmingas. Išsamesnei informacijai apie šią problemą, <a href=\"{url}\">žiūrėkite įrašą mūsų forume</a>.",
     "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "Atnaujinimas buvo nesėkmingas. Prašome pranešti apie šią problemą <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud bendruomenei</a>.",
+    "Continue to {productName}" : "Tęsti {productName}",
+    "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["Atnaujinimas sėkmingas. Nukreipiama į  {productName} per %n sek.","Atnaujinimas sėkmingas. Nukreipiama į {productName} per %n sek.","Atnaujinimas sėkmingas. Nukreipiama į  {productName} per %n seconds.","Atnaujinimas sėkmingas. Nukreipiama į {productName} per %n sekundes."],
+    "Applications menu" : "Programų meniu",
+    "Apps" : "Programėlės",
     "More apps" : "Daugiau programėlių",
     "_{count} notification_::_{count} notifications_" : ["{count} pranešimas","{count} pranešimai","{count} pranešimų","{count} pranešimas"],
     "No" : "Ne",
     "Yes" : "Taip",
+    "Failed to add the public link to your Nextcloud" : "Nepavyko pridėti viešosios nuorodos į jūsų Nextcloud",
+    "Create share" : "Sukurti viešinį",
+    "Direct link copied to clipboard" : "Tiesioginė nuoroda nukopijuota į iškarpinę",
+    "Please copy the link manually:" : "Nukopijuokite nuorodą rankiniu būdu:",
+    "Clear search" : "Išvalyti paiešką",
+    "Searching …" : "Ieškoma…",
+    "Start typing to search" : "Rašykite norėdami atlikti paiešką",
+    "Today" : "Šiandien",
+    "Last 7 days" : "Paskutinės 7 dienos",
+    "Last 30 days" : "Paskutinės 30 dienų",
+    "Date" : "Data",
+    "People" : "Žmonės",
+    "Results" : "Rezultatai",
+    "Load more results" : "Įkelti daugiau rezultatų",
     "Log in" : "Prisijungti",
     "Logging in …" : "Prisijungiama …",
+    "Log in to {productName}" : "Prisijunkite prie {productName}",
+    "Wrong login or password." : "Neteisingas prisijungimas ar slaptažodis.",
+    "This account is disabled" : "Ši paskyra yra išjungta",
+    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Dėl daugkartinių nesėkmingų bandymų prisijungti iš jūsų IP adreso, prisijungimai bus uždelsti iki 30 sekundžių.",
+    "Account name or email" : "Paskyros vardas ar el. paštas",
+    "Account name" : "Paskyros pavadinimas",
     "Server side authentication failed!" : "Autentikacija serveryje nepavyko!",
     "Please contact your administrator." : "Susisiekite su savo administratoriumi.",
-    "Temporary error" : "Laikina klaida",
-    "Please try again." : "Bandykite dar kartą.",
     "An internal error occurred." : "Įvyko vidinė klaida.",
     "Please try again or contact your administrator." : "Pabandykite dar kartą arba susisiekite su savo administratoriumi.",
     "Password" : "Slaptažodis",
-    "Log in to {productName}" : "Prisijunkite prie {productName}",
-    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Dėl daugkartinių nesėkmingų bandymų prisijungti iš jūsų IP adreso, prisijungimai bus uždelsti iki 30 sekundžių.",
     "Log in with a device" : "Prisijungti naudojant įrenginį",
+    "Login or email" : "Prisijungimas ar el. paštas",
     "Your account is not setup for passwordless login." : "Jūsų paskyra nėra nustatyta prisijungimui be slaptažodžio.",
-    "Browser not supported" : "Naršyklė nepalaikoma",
-    "Passwordless authentication is not supported in your browser." : "Tapatybės nustatymas be slaptažodžio nėra palaikomas jūsų naršyklėje.",
     "Your connection is not secure" : "Jūsų ryšys nėra saugus",
     "Passwordless authentication is only available over a secure connection." : "Tapatybės nustatymas be slaptažodžio yra prieinamas tik per saugų ryšį.",
+    "Browser not supported" : "Naršyklė nepalaikoma",
+    "Passwordless authentication is not supported in your browser." : "Tapatybės nustatymas be slaptažodžio nėra palaikomas jūsų naršyklėje.",
     "Reset password" : "Atstatyti slaptažodį",
-    "Couldn't send reset email. Please contact your administrator." : "Nepavyko išsiųsti atstatymo el. laiško. Susisiekite su savo administratoriumi.",
     "Back to login" : "Grįžti prie prisijungimo",
+    "Couldn't send reset email. Please contact your administrator." : "Nepavyko išsiųsti atstatymo el. laiško. Susisiekite su savo administratoriumi.",
     "New password" : "Naujas slaptažodis",
     "I know what I'm doing" : "Aš žinau ką darau",
+    "Schedule work & meetings, synced with all your devices." : "Planuokite su visais jūsų įrenginiais sinchronizuotus darbus ir susitikimus.",
+    "Keep your colleagues and friends in one place without leaking their private info." : "Saugokite savo kolegas bei draugus vienoje vietoje, neatskleisdami jų asmeninės informacjios.",
+    "Simple email app nicely integrated with Files, Contacts and Calendar." : "Paprasta el. pašto programėlė, tvarkingai integruota su failais, adresatais ir kalendoriumi.",
     "Recommended apps" : "Rekomenduojamos programėlės",
     "Loading apps …" : "Įkeliamos programėlės…",
-    "Installing apps …" : "Įdiegiamos programėlės…",
     "App download or installation failed" : "Programėlės atsisiuntimas ar įdiegimas patyrė nesėkmę",
     "Cannot install this app because it is not compatible" : "Nepavyksta įdiegti šios programėlės, nes ji yra nesuderinama",
     "Cannot install this app" : "Nepavyksta įdiegti šios programėlės",
     "Skip" : "Praleisti",
+    "Installing apps …" : "Įdiegiamos programėlės…",
     "Install recommended apps" : "Įdiegti rekomenduojamas programėles",
-    "Schedule work & meetings, synced with all your devices." : "Planuokite su visais jūsų įrenginiais sinchronizuotus darbus ir susitikimus.",
-    "Keep your colleagues and friends in one place without leaking their private info." : "Saugokite savo kolegas bei draugus vienoje vietoje, neatskleisdami jų asmeninės informacjios.",
-    "Simple email app nicely integrated with Files, Contacts and Calendar." : "Paprasta el. pašto programėlė, tvarkingai integruota su failais, adresatais ir kalendoriumi.",
+    "Settings menu" : "Nustatymų meniu",
+    "Loading your contacts …" : "Įkeliami jūsų adresatai…",
+    "Looking for {term} …" : "Ieškoma {term} ...",
     "Search contacts" : "Ieškoti adresatų",
     "Reset search" : "Atstatyti paiešką",
     "Search contacts …" : "Ieškoti adresatų…",
@@ -120,30 +151,38 @@ OC.L10N.register(
     "No contacts found" : "Adresatų nerasta",
     "Show all contacts" : "Rodyti visus adresatus",
     "Install the Contacts app" : "Įdiegti adresatų programėlę",
-    "Loading your contacts …" : "Įkeliami jūsų adresatai…",
-    "Looking for {term} …" : "Ieškoma {term} ...",
-    "Search for {name} only" : "Ieškoti tik {name}",
-    "Start typing to search" : "Rašykite norėdami atlikti paiešką",
-    "Loading more results …" : "Įkeliama daugiau rezultatų…",
-    "Load more results" : "Įkelti daugiau rezultatų",
     "Search" : "Ieškoti",
     "No results for {query}" : "{query} negrąžino jokių rezultatų",
-    "An error occurred while searching for {type}" : "Ieškant {type}, įvyko klaida",
     "_Please enter {minSearchLength} character or more to search_::_Please enter {minSearchLength} characters or more to search_" : ["Norėdami atlikti paiešką, įveskite {minSearchLength} ar daugiau simbolių","Norėdami atlikti paiešką, įveskite {minSearchLength} ar daugiau simbolių","Norėdami atlikti paiešką, įveskite {minSearchLength} ar daugiau simbolių","Norėdami atlikti paiešką, įveskite {minSearchLength} ar daugiau simbolių"],
+    "An error occurred while searching for {type}" : "Ieškant {type}, įvyko klaida",
+    "Search for {name} only" : "Ieškoti tik {name}",
+    "Loading more results …" : "Įkeliama daugiau rezultatų…",
     "Forgot password?" : "Pamiršote slaptažodį?",
     "Back" : "Atgal",
-    "Edit Profile" : "Taisyti profilį",
-    "The headline and about sections will show up here" : "Čia bus rodoma santrauka apie jus bei kita su jumis susijusi informacija",
-    "You have not added any info yet" : "Jūs kol kas nesate pridėję jokios informacijos",
-    "{user} has not added any info yet" : "Naudotojas {user} kol kas nėra pridėjęs jokios informacijos",
-    "Search {types} …" : "Ieškoti {types}…",
-    "Date" : "Data",
-    "Today" : "Šiandien",
-    "Not found" : "Nerasta",
-    "People" : "Žmonės",
-    "Searching …" : "Ieškoma…",
+    "More actions" : "Daugiau veiksmų",
+    "Security warning" : "Saugumo įspėjimas",
+    "Storage & database" : "Saugykla ir duomenų bazė",
+    "Data folder" : "Duomenų aplankas",
+    "Install and activate additional PHP modules to choose other database types." : "Įdiekite ir aktyvuokite papildomus PHP modulius, kad pasirinktumėte kitus duomenų bazės tipus.",
+    "For more details check out the documentation." : "Išsamesnei informacijai, žiūrėkite dokumentaciją.",
+    "Performance warning" : "Sistemos našumo problemos perspėjimas",
+    "You chose SQLite as database." : "Jūs kaip duomenų bazę pasirinkote SQLite.",
+    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite turėtų būti naudojama tik minimaliems ir plėtojimo egzemplioriams. Darbiniam egzemplioriui rekomenduojame naudoti kitą duomenų bazės vidinę pusę.",
+    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "Jei sinchronizavimui naudojate kliento programas, tuomet SQLite naudojimas yra primygtinai nerekomenduojamas.",
+    "Database user" : "Duomenų bazės naudotojas",
+    "Database password" : "Duomenų bazės slaptažodis",
+    "Database name" : "Duomenų bazės pavadinimas",
+    "Database tablespace" : "Duomenų bazės loginis saugojimas",
+    "Database host" : "Duomenų bazės serveris",
+    "Installing …" : "Įdiegiama…",
+    "Install" : "Įdiegti",
+    "Need help?" : "Reikia pagalbos?",
+    "See the documentation" : "Žiūrėkite dokumentaciją",
+    "This browser is not supported" : "Ši naršyklė nepalaikoma",
+    "Your browser is not supported. Please upgrade to a newer version or a supported one." : "Jūsų naršyklė yra nepalaikoma. Atnaujinkite į naujesnę versiją arba naudokite palaikomą naršyklę.",
+    "Continue with this unsupported browser" : "Tęsti naudojant šią nepalaikomą naršyklę",
     "Supported versions" : "Palaikomos versijos",
-    "Settings menu" : "Nustatymų meniu",
+    "Search {types} …" : "Ieškoti {types}…",
     "Choose" : "Pasirinkti",
     "Copy to {target}" : "Kopijuoti į {target}",
     "Copy" : "Kopijuoti",
@@ -177,11 +216,6 @@ OC.L10N.register(
     "Type to search for existing projects" : "Rašykite norėdami ieškoti esamų projektų",
     "New in" : "Nauja",
     "View changelog" : "Rodyti keitinių žurnalą",
-    "Very weak password" : "Labai silpnas slaptažodis",
-    "Weak password" : "Silpnas slaptažodis",
-    "So-so password" : "Neblogas slaptažodis",
-    "Good password" : "Geras slaptažodis",
-    "Strong password" : "Stiprus slaptažodis",
     "No action available" : "Jokie veiksmai negalimi",
     "Error fetching contact actions" : "Klaida gaunant veiksmus darbui su adresatais",
     "Non-existing tag #{tag}" : "Neegzistuojanti žymė #{tag}",
@@ -192,22 +226,20 @@ OC.L10N.register(
     "Collaborative tags" : "Bendradarbiavimo žymės",
     "No tags found" : "Nerasta jokių žymių",
     "Personal" : "Asmeniniai",
-    "Apps" : "Programėlės",
+    "Accounts" : "Paskyros",
     "Admin" : "Administravimas",
     "Help" : "Pagalba",
     "Access forbidden" : "Prieiga uždrausta",
-    "Profile not found" : "Profilis nerastas",
-    "The profile does not exist." : "Profilio nėra.",
-    "Back to %s" : "Atgal į %s",
     "Page not found" : "Puslapis nerastas",
+    "Back to %s" : "Atgal į %s",
     "Too many requests" : "Per daug užklausų",
     "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Iš jūsų tinklo buvo per daug užklausų. Bandykite dar kartą vėliau arba, jeigu tai klaida, susisiekite su savo administratoriumi.",
     "Error" : "Klaida",
-    "Previous" : "Ankstesnis",
     "Internal Server Error" : "Vidinė serverio klaida",
     "The server was unable to complete your request." : "Serveriui nepavyko įvykdyti jūsų užklausos.",
     "If this happens again, please send the technical details below to the server administrator." : "Jei tai pasikartos, prašome nusiųsti serverio administratoriui žemiau esančią techninę informaciją.",
     "More details can be found in the server log." : "Detalesnė informacija yra sistemos žurnale.",
+    "For more details see the documentation ↗." : "Išsamesnei informacijai žiūrėkite dokumentaciją ↗.",
     "Technical details" : "Techniniai duomenys",
     "Remote Address: %s" : "Nuotolinis adresas: %s",
     "Request ID: %s" : "Užklausos ID: %s",
@@ -217,30 +249,6 @@ OC.L10N.register(
     "File: %s" : "Failas: %s",
     "Line: %s" : "Eilutė: %s",
     "Trace" : "Sekti",
-    "Security warning" : "Saugumo įspėjimas",
-    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Jūsų duomenų katalogas ir failai, tikriausiai, yra prieinami per internetą, nes .htaccess failas neveikia.",
-    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Išsamesnei informacijai apie tai kaip tinkamai sukonfigūruoti savo serverį, žiūrėkite <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">dokumentaciją</a>.",
-    "Create an <strong>admin account</strong>" : "Sukurkite <strong>administratoriaus paskyrą</strong>",
-    "Show password" : "Rodyti slaptažodį",
-    "Toggle password visibility" : "Perjungti slaptažodžio matomumą",
-    "Storage & database" : "Saugykla ir duomenų bazė",
-    "Data folder" : "Duomenų aplankas",
-    "Configure the database" : "Konfigūruokite duomenų bazę",
-    "Only %s is available." : "Yra prieinama tik %s.",
-    "Install and activate additional PHP modules to choose other database types." : "Įdiekite ir aktyvuokite papildomus PHP modulius, kad pasirinktumėte kitus duomenų bazės tipus.",
-    "For more details check out the documentation." : "Išsamesnei informacijai, žiūrėkite dokumentaciją.",
-    "Database password" : "Duomenų bazės slaptažodis",
-    "Database name" : "Duomenų bazės pavadinimas",
-    "Database tablespace" : "Duomenų bazės loginis saugojimas",
-    "Database host" : "Duomenų bazės serveris",
-    "Performance warning" : "Sistemos našumo problemos perspėjimas",
-    "You chose SQLite as database." : "Jūs kaip duomenų bazę pasirinkote SQLite.",
-    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite turėtų būti naudojama tik minimaliems ir plėtojimo egzemplioriams. Darbiniam egzemplioriui rekomenduojame naudoti kitą duomenų bazės vidinę pusę.",
-    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "Jei sinchronizavimui naudojate kliento programas, tuomet SQLite naudojimas yra primygtinai nerekomenduojamas.",
-    "Install" : "Įdiegti",
-    "Installing …" : "Įdiegiama…",
-    "Need help?" : "Reikia pagalbos?",
-    "See the documentation" : "Žiūrėkite dokumentaciją",
     "Could not remove CAN_INSTALL from the config folder. Please remove this file manually." : "Nepavyko iš konfigūracijos aplanko pašalinti failo CAN_INSTALL. Pašalinkite šį failą rankiniu būdu.",
     "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Sistemos veikimui reikalingas JavaScript palaikymas. Prašome {linkstart}įjungti JavaScript palaikymą{linkend} ir atnaujinti puslapį.",
     "Skip to main content" : "Pereiti į pagrindinį turinį",
@@ -257,6 +265,7 @@ OC.L10N.register(
     "Account connected" : "Paskyra prijungta",
     "Your client should now be connected!" : "Dabar, jūsų kliento programa turėtų būti prijungta!",
     "You can close this window." : "Galite užverti šį langą.",
+    "Previous" : "Ankstesnis",
     "This share is password-protected" : "Šis viešinys yra apsaugotas slaptažodžiu",
     "Email address" : "El. pašto adresas",
     "Password sent!" : "Slaptažodis išsiųstas!",
@@ -288,51 +297,24 @@ OC.L10N.register(
     "This %s instance is currently in maintenance mode, which may take a while." : "Šis %s egzempliorius šiuo metu yra techninės priežiūros veiksenoje, kas savo ruožtu gali šiek tiek užtrukti.",
     "This page will refresh itself when the instance is available again." : "Šis puslapis bus įkeltas iš naujo, kai egzempliorius bus ir vėl prieinamas.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Susisiekite su savo sistemos administratoriumi, jei šis pranešimas nedingsta arba, jei jis pasirodė netikėtai.",
-    "The user limit of this instance is reached." : "Yra pasiekta šio egzemplioriaus naudotojų riba.",
-    "Your web server is not yet properly set up to allow file synchronization, because the WebDAV interface seems to be broken." : "Jūsų svetainės serveris nėra tinkamai sukonfiguruotas, Failų sinchronizavimas negalimas, nes neveikia WebDAV interfeisas.",
-    "It was not possible to execute the cron job via CLI. The following technical errors have appeared:" : "Buvo neįmanoma įvykdyti cron užduotį per komandų eilutę. Atsirado šios techninės klaidos:",
-    "Your PHP does not have FreeType support, resulting in breakage of profile pictures and the settings interface." : "Jūsų PHP neturi FreeType palaikymo, kas savo ruožtu sąlygoja profilio paveikslėlių ir nustatymų sąsajos neteisingą atvaizdavimą.",
-    "Missing optional column \"{columnName}\" in table \"{tableName}\"." : "Lentelėje „{tableName}“ trūksta nebūtino stulpelio „{columnName}“.",
-    "This instance is missing some recommended PHP modules. For improved performance and better compatibility it is highly recommended to install them." : "Šiame egzemplioriuje trūksta kai kurių rekomenduojamų PHP modulių. Pagerintam našumui ir geresniam suderinamumui yra primygtinai rekomenduojama juos įdiegti.",
-    "This is particularly recommended when using the desktop client for file synchronisation." : "Tai ypač rekomenduojama failų sinchronizavimui naudojant darbalaukio kliento programą.",
-    "The PHP memory limit is below the recommended value of 512MB." : "PHP atminties riba yra žemiau rekomenduojamos 512MB reikšmės.",
-    "Account name or email" : "Paskyros vardas ar el. paštas",
-    "Wrong username or password." : "Neteisingas naudotojo vardas ar slaptažodis.",
-    "User disabled" : "Naudotojas išjungtas",
-    "Username or email" : "Naudotojas arba el. paštas",
-    "Open settings menu" : "Atverti nustatymų meniu",
-    "Settings" : "Nustatymai",
-    "Show all contacts …" : "Rodyti visus adresatus…",
-    "No files in here" : "Čia failų nėra",
-    "New folder" : "Naujas aplankas",
-    "No more subfolders in here" : "Čia daugiau nebėra poaplankių",
-    "Name" : "Pavadinimas",
-    "Size" : "Dydis",
-    "Modified" : "Pakeista",
-    "\"{name}\" is an invalid file name." : "„{name}“ yra neteisingas failo pavadinimas.",
-    "File name cannot be empty." : "Failo pavadinimas negali būti tuščias.",
-    "\"/\" is not allowed inside a file name." : "Failo pavadinime simbolis „/“ draudžiamas.",
-    "\"{name}\" is not an allowed filetype" : "\"{name}\" yra neleistinas failo tipas",
-    "{newName} already exists" : "{newName} jau yra",
-    "Error loading file picker template: {error}" : "Klaida įkeliant failo parinkimo ruošinį: {error}",
+    "You have not added any info yet" : "Jūs kol kas nesate pridėję jokios informacijos",
+    "{user} has not added any info yet" : "Naudotojas {user} kol kas nėra pridėjęs jokios informacijos",
+    "Edit Profile" : "Taisyti profilį",
+    "The headline and about sections will show up here" : "Čia bus rodoma santrauka apie jus bei kita su jumis susijusi informacija",
     "Error loading message template: {error}" : "Klaida įkeliant žinutės ruošinį: {error}",
-    "Show list view" : "Rodyti sąrašo rodinį",
-    "Show grid view" : "Rodyti tinklelio rodinį",
-    "Pending" : "Vykdoma",
-    "Home" : "Namai",
-    "Copy to {folder}" : "Kopijuoti į {folder}",
-    "Move to {folder}" : "Perkelti į {folder}",
-    "Authentication required" : "Reikalingas tapatybės nustatymas",
-    "This action requires you to confirm your password" : "Šis veiksmas reikalauja, kad įvestumėte savo slaptažodį",
-    "Confirm" : "Patvirtinti",
-    "Failed to authenticate, try again" : "Nepavyko nustatyti tapatybės, bandykite dar kartą",
-    "Users" : "Naudotojai",
-    "Username" : "Naudotojo vardas",
-    "Database user" : "Duomenų bazės naudotojas",
-    "Confirm your password" : "Patvirtinkite savo slaptažodį",
-    "App token" : "Išorinės sistemos įskiepio kodas",
-    "Alternative log in using app token" : "Alternatyvus prisijungimas naudojant programėlės atpažinimo raktą",
-    "Please use the command line updater because you have a big instance with more than 50 users." : "Naudokite komandų eilutės atnaujinimo programą, nes turite didelį egzempliorių su daugiau nei 50 naudotojų.",
-    "Apps and Settings" : "Programėlės ir nustatymai"
+    "Very weak password" : "Labai silpnas slaptažodis",
+    "Weak password" : "Silpnas slaptažodis",
+    "So-so password" : "Neblogas slaptažodis",
+    "Good password" : "Geras slaptažodis",
+    "Strong password" : "Stiprus slaptažodis",
+    "Profile not found" : "Profilis nerastas",
+    "The profile does not exist." : "Profilio nėra.",
+    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Jūsų duomenų katalogas ir failai, tikriausiai, yra prieinami per internetą, nes .htaccess failas neveikia.",
+    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Išsamesnei informacijai apie tai kaip tinkamai sukonfigūruoti savo serverį, žiūrėkite <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">dokumentaciją</a>.",
+    "Show password" : "Rodyti slaptažodį",
+    "Toggle password visibility" : "Perjungti slaptažodžio matomumą",
+    "Configure the database" : "Konfigūruokite duomenų bazę",
+    "Only %s is available." : "Yra prieinama tik %s.",
+    "Database account" : "Duomenų bazės paskyra"
 },
 "nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");
