@@ -201,7 +201,6 @@ OC.L10N.register(
     "Path is already shared with this group" : "Path is already shared with this group",
     "Link sharing is not allowed" : "Link sharing is not allowed",
     "Public upload is not allowed" : "Public upload is not allowed",
-    "Path contains files shared with you" : "Path contains files shared with you",
     "Sharing is disabled" : "Sharing is disabled",
     "Sharing is disabled for you" : "Sharing is disabled for you",
     "Cannot share with the share owner" : "Cannot share with the share owner",
@@ -329,7 +328,6 @@ OC.L10N.register(
     "The audio to transcribe" : "The audio to transcribe",
     "Transcription" : "Transcription",
     "The transcribed text" : "The transcribed text",
-    "ContextAgent" : "ContextAgent",
     "Chat with an agent" : "Chat with an agent",
     "Chat message" : "Chat message",
     "A chat message to send to the agent." : "A chat message to send to the agent.",
